"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.defaultMessageRetryStrategy = void 0;
/**
 * Get the default message retry strategy. This strategy checks that the maximum
 * of finished attempts is not exceeded. The number can be defined in the
 * `config.settings.maxAttempts` variable. If the error is a PostgreSQL
 * serialization error it will always be retried.
 */
const defaultMessageRetryStrategy = (config) => {
    return (message, error) => {
        if (error.innerError &&
            'code' in error.innerError &&
            error.innerError.code === '40001') {
            // always retry PostgreSQL serialization_failure
            return true;
        }
        return message.finishedAttempts < config.settings.maxAttempts;
    };
};
exports.defaultMessageRetryStrategy = defaultMessageRetryStrategy;
//# sourceMappingURL=message-retry-strategy.js.map